@@ -4,7 +4,7 @@
 #
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '2.232012'; # TRIAL
+$Parallel::WorkUnit::VERSION = '2.232040'; # TRIAL
 use v5.8;
 
 # ABSTRACT: Provide multi-paradigm forking with ability to pass back data
@@ -39,7 +39,6 @@ sub use_anyevent {
 
         my ($old_val) = $self->{use_anyevent};
         $self->{use_anyevent} = $val;
-        $self->use_io_async(undef) if $val;
 
         # Trigger
         $self->_set_anyevent( $val, $old_val );
@@ -51,26 +50,6 @@ sub use_anyevent {
 }
 
 
-
-sub use_io_async {
-    if ( $#_ == 0 ) {
-        return shift->{use_io_async};
-    } elsif ( $#_ == 1 ) {
-        my ( $self, $val ) = @_;
-
-        my ($old_val) = $self->{use_io_async};
-        $self->{use_io_async} = $val;
-        $self->use_anyevent(undef) if $val;
-
-        # Trigger
-        $self->_set_io_async( $val, $old_val );
-
-        return $val;
-    } else {
-        confess("Invalid call");
-    }
-}
-
 # XXX: Add validation that _cv is a Maybe[AnyEvent::CondVar]
 sub _cv {
     if ( $#_ == 0 ) {
@@ -84,19 +63,6 @@ sub _cv {
     }
 }
 
-# XXX: Add validation that _future is a Maybe[IO::Async::Future]
-sub _future {
-    if ( $#_ == 0 ) {
-        return shift->{_future};
-    } elsif ( $#_ == 1 ) {
-        my ( $self, $val ) = @_;
-        $self->{_future} = $val;
-        return $val;
-    } else {
-        confess("Invalid call");
-    }
-}
-
 # XXX: Add validation that _last_error is a Maybe[Str]
 sub _last_error {
     if ( $#_ == 0 ) {
@@ -272,9 +238,6 @@ sub new {
         if (exists $args{use_anyevent}) {
             $self->use_anyevent($args{use_anyevent});
         }
-        if (exists $args{use_io_async}) {
-            $self->use_io_async($args{use_io_async});
-        }
         if (exists $args{max_children}) {
             $self->max_children($args{max_children});
         }
@@ -340,11 +303,6 @@ sub async {
             $self->_add_anyevent_watcher($pid);
         }
 
-        # Set up IO::Async listener if appropriate
-        if ( $self->use_io_async() ) {
-            $self->_add_io_async_watcher($pid);
-        }
-
         return $pid;
 
     } else {
@@ -403,11 +361,6 @@ sub waitall {
     if ( scalar( keys %{ $self->_subprocs } ) == 0 ) {
         if ( $self->use_anyevent ) {
             $self->_cv( AnyEvent->condvar );
-            $self->_future(undef);
-        }
-        if ( $self->use_io_async ) {
-            $self->_future( $self->use_io_async->new_future() );
-            $self->_cv(undef);
         }
 
         return $self->_get_and_reset_ordered_responses();
@@ -426,19 +379,6 @@ sub waitall {
         return $self->_get_and_reset_ordered_responses();
     }
 
-    # Using Futures?
-    if ( defined( $self->_future) ) {
-        $self->_future->get();
-        if ( defined( $self->_last_error ) ) {
-            my $err = $self->_last_error;
-            $self->_last_error(undef);
-
-            die($err);
-        }
-
-        return $self->_get_and_reset_ordered_responses();
-    }
-
     # Tail recursion
     if ( $self->_waitone() ) { goto &waitall }
 
@@ -467,7 +407,7 @@ sub waitone {
 
     my $rv = $self->_waitone();
 
-    # Using AnyEvent/IO::Async?
+    # Using AnyEvent?
     if ( defined( $self->_last_error ) ) {
         my $err = $self->_last_error;
         $self->_last_error(undef);
@@ -479,7 +419,7 @@ sub waitone {
 }
 
 # Meat of waitone (but doesn't handle returning an exception when using
-# anyevent / IO::Async)
+# anyevent)
 sub _waitone {
     if ( $#_ != 0 ) { confess 'invalid call'; }
     my ($self) = @_;
@@ -534,7 +474,7 @@ sub wait {
     return $rv;
 }
 
-# Internal version that doesn't check for AnyEvent/IO::Async die needs
+# Internal version that doesn't check for AnyEvent die needs
 sub _wait {
     if ( $#_ != 1 ) { confess 'invalid call'; }
     my ( $self, $pid ) = @_;
@@ -681,8 +621,8 @@ sub _read_result_from_buffer {
           . $caller->[2]
           . ") died with error: $data";
 
-        if ( $self->use_anyevent || $self->use_io_async ) {
-            # Can't throw events with anyevent / IO::Async
+        if ( $self->use_anyevent ) {
+            # Can't throw events with anyevent
             $self->_last_error($err);
         } else {
             # Otherwise we do throw it
@@ -742,8 +682,8 @@ sub _read_result_from_fh {
           . $caller->[2]
           . ") died with error: $data";
 
-        if ( $self->use_anyevent || $self->use_io_async ) {
-            # Can't throw events with anyevent / IO::Async
+        if ( $self->use_anyevent ) {
+            # Can't throw events with anyevent
             $self->_last_error($err);
         } else {
             # Otherwise we do throw it
@@ -800,7 +740,6 @@ sub _set_anyevent {
         }
 
         $self->_cv( AnyEvent->condvar );
-        $self->_future( undef );
 
     } elsif ( $old && ( !$new ) ) {
         # We are tearing down AnyEvent
@@ -818,41 +757,6 @@ sub _set_anyevent {
     return;
 }
 
-# Sets up IO::Async or tears it down as needed
-sub _set_io_async {
-    if ( $#_ < 1 ) { confess 'invalid call' }
-    if ( $#_ > 2 ) { confess 'invalid call' }
-    my ( $self, $new, $old ) = @_;
-
-    if ( ( !$old ) && $new ) {
-        # We are setting up IO::Async
-        require IO::Async::Stream;
-
-        if ( defined( $self->_subprocs() ) ) {
-            foreach my $pid ( keys %{ $self->_subprocs() } ) {
-                $self->_add_io_async_watcher($pid);
-            }
-        }
-
-        $self->_cv( undef );
-        $self->_future( $new->new_future );
-
-    } elsif ( $old && ( !$new ) ) {
-        # We are tearing down IO::Async
-
-        if ( defined( $self->_subprocs() ) ) {
-            foreach my $pid ( keys %{ $self->_subprocs() } ) {
-                my $proc = $self->_subprocs()->{$pid};
-
-                $proc->{watcher} = undef;
-            }
-        }
-
-        $self->_future(undef);
-    }
-    return;
-}
-
 # Sets up the listener for AnyEvent
 sub _add_anyevent_watcher {
     if ( $#_ != 1 ) { confess 'invalid call' }
@@ -879,48 +783,12 @@ sub _add_anyevent_watcher {
     return;
 }
 
-# Sets up the listener for IO::Async
-sub _add_io_async_watcher {
-    if ( $#_ != 1 ) { confess 'invalid call' }
-    my ( $self, $pid ) = @_;
-
-    my $proc = $self->_subprocs()->{$pid};
-
-    $proc->{watcher} = IO::Async::Stream->new(
-        read_handle       => $proc->{fh},
-        close_on_read_eof => undef,
-        on_read           => sub {
-            my ($obj, $buffref, $eof) = @_;
-            $proc->{rawbuff} = $$buffref;
-
-            my ($type, $size, $buffer) = split /\n/, $$buffref, 3;
-            if ($eof or (defined($buffer) && length($buffer) == $size)) {
-                $self->_wait($pid);
-                if ( scalar( keys %{ $self->_subprocs() } ) == 0 ) {
-                    my $oldfuture = $self->_future;
-                    $self->_future( $self->use_io_async->new_future );
-                    $oldfuture->done();
-                }
-
-                # Start queued children, if needed
-                $self->_start_queued_children();
-            }
-
-            return 0;
-        },
-    );
-    $self->use_io_async->add($proc->{watcher});
-
-    return;
-}
-
 # Used to clear all sub-processes, etc, in child process.
 sub _clear_all {
     if ( $#_ != 0 ) { confess 'invalid call' }
     my ( $self ) = @_;
 
     $self->_cv(undef);
-    $self->_future(undef);
     $self->_last_error(undef);
     $self->_ordered_count(0);
     $self->_ordered_responses( [] );
@@ -996,7 +864,7 @@ Parallel::WorkUnit - Provide multi-paradigm forking with ability to pass back da
 
 =head1 VERSION
 
-version 2.232012
+version 2.232040
 
 =head1 SYNOPSIS
 
@@ -1046,18 +914,6 @@ version 2.232012
   $wu->waitall();  # Not strictly necessary, callbacks happen within event loop
 
 
-  #
-  # IO::Async Interface (only usable if IO::Async is installed)
-  #
-  use IO::Async::Loop;
-  my $loop = IO::Async::Loop->new;
-  my $wu = Parallel::WorkUnit->new();
-
-  $wu->use_io_async($loop);
-  $wu->async( sub { ... }, \&callback );
-  $loop->run;
-
-
   #
   # Just spawn something into another process, don't capture return
   # values, don't allow waiting on process, etc.
@@ -1074,10 +930,8 @@ the information, serialized, back).  It was designed to be very simple
 for a developer to use, with the ability to pass reasonably large amounts
 of data back to the parent process.
 
-This module is also designed to work with AnyEvent or IO::Async (preferred
-for new code) when desired, but it does not require AnyEvent or IO::Async
-to be installed for other functionality to
-work.
+This module is also designed to work with AnyEvent when desired, but it
+does not require AnyEvent to be installed for other functionality to work.
 
 There are many other Parallel::* applications in CPAN - it would be worth
 any developer's time to look through those and choose the best one.
@@ -1098,20 +952,6 @@ the C<AnyEvent> event loop.
 
 The default value is false.
 
-=head2 use_io_async
-
-  $wu->use_io_async($loop);
-
-When set to an IO::Async::Loop, creates IO::Async watchers for each
-asyncronous or queued job.  The equivilent of an C<IO::Async> condition
-variable C<recv()>, used when all processes finish executing, is the
-C<waitall()> method.  However, the processes are integrated into a
-standard C<IO::Async> loop, so it isn't strictly necessary to call C<waitall()>.
-In addition, a call to C<waitall()> will execute other processes in
-the C<IO::Async> event loop.
-
-The default value is false.
-
 =head2 max_children
 
   $wu->max_children(5);
